==> liitos-2022.12.6.tar.gz: liitos-2022.12.6/README.md <==
# liitos

Splice (Finnish: liitos) contributions.

[License: MIT](https://git.sr.ht/~sthagen/liitos/tree/default/item/LICENSE)

[![version](https://img.shields.io/pypi/v/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![downloads](https://pepy.tech/badge/liitos/month)](https://pepy.tech/project/liitos)
[![wheel](https://img.shields.io/pypi/wheel/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-versions](https://img.shields.io/pypi/pyversions/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-implementations](https://img.shields.io/pypi/implementation/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)

## Documentation

User and developer [documentation of liitos](https://codes.dilettant.life/docs/liitos).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of liitos](https://todo.sr.ht/~sthagen/liitos).

## Primary Source repository

The primary source of `liitos` lives somewhere on a mountain in Central Switzerland.
But, we use decentralized version control (git), so any clone can become the source to everyone's benefit, no central only code.
Anyway, the preferred public clones of `liitos` are:

* [on codeberg](https://codeberg.org/sthagen/liitos) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/liitos) - a collection of tools useful for software development.

# Status

Experimental.

**Note**: The default branch is `default`.

==> liitos-2023.1.17.tar.gz: liitos-2023.1.17/README.md <==
# Liitos

Splice (Finnish: liitos) contributions.

[License: MIT](https://git.sr.ht/~sthagen/liitos/tree/default/item/LICENSE)

Third party dependencies are documented in the folder [third-party](third-party/README.md).

[![version](https://img.shields.io/pypi/v/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![downloads](https://pepy.tech/badge/liitos/month)](https://pepy.tech/project/liitos)
[![wheel](https://img.shields.io/pypi/wheel/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-versions](https://img.shields.io/pypi/pyversions/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)
[![supported-implementations](https://img.shields.io/pypi/implementation/liitos.svg?style=flat)](https://pypi.python.org/pypi/liitos/)

## Documentation

User and developer [documentation of liitos](https://codes.dilettant.life/docs/liitos).

## Bug Tracker

Feature requests and bug reports are best entered in the [todos of liitos](https://todo.sr.ht/~sthagen/liitos).

## Primary Source repository

The main source of `liitos` is on a mountain in central Switzerland.
We use distributed version control (git).
There is no central hub.
Every clone can become a new source for the benefit of all.
The preferred public clones of `liitos` are:

* [on codeberg](https://codeberg.org/sthagen/liitos) - a democratic community-driven, non-profit software development platform operated by Codeberg e.V.
* [at sourcehut](https://git.sr.ht/~sthagen/liitos) - a collection of tools useful for software development.

# Status

Experimental.

**Note**: The default branch is `default`.
